@@ -4,8 +4,8 @@ import posixpath
 
 class HTTPEndPoint(object):
     def __init__(self):
-        self._base = 'http://0.0.0.0:8888/api/v1/public/'
-        #self._base = 'http://4cn-api.cptec.inpe.br/api/v1/public/'
+        #self._base = 'http://0.0.0.0:8888/api/v1/public/'
+        self._base = 'http://4cn-api.cptec.inpe.br/api/v1/public/'
 
 class PClimaURL(HTTPEndPoint):
 
